@@ -177,7 +177,6 @@ class RhythmViewer(gtk.Frame):
         self.clear()
 
 class Gui(abstract.Gui, abstract.RhythmAddOnGuiClass):
-    num_buttons_in_row = 8
     def __init__(self, teacher):
         abstract.Gui.__init__(self, teacher)
         self.m_key_bindings = {'backspace_ak': self.on_backspace}
@@ -258,7 +257,7 @@ class Gui(abstract.Gui, abstract.RhythmAddOnGuiClass):
     def play_users_answer(self, widget):
         if self.g_rhythm_viewer.m_data:
             rhythm = " ".join([const.RHYTHMS[c] for c in self.g_rhythm_viewer.m_data])
-            self.m_t.play_rhythm(r"\staff{ %s }" % rhythm)
+            self.m_t.play_rhythm(r"\rhythmstaff{ \time 1000000/4 %s }" % rhythm)
     def guess_element(self, sender, i):
         if self.m_t.q_status == self.QSTATUS_NO:
             self.g_rhythm_viewer.flash(_("Click 'New' to begin."))
